@@ -423,4 +423,10 @@ def getGraph(filename=None,graphname='graphdb',storage=None):
     root = connection.root()
     if not root.has_key(graphname):
         root[graphname]=GraphDB()
-    return root[graphname]
+    g = root[graphname]
+    g._v_root = root
+    g._v_connection = connection
+    g._v_db = db
+    g._v_storage = storage
+
+    return g
